package shows

import (
	"errors"
	"net/http"

	"github.com/gorilla/mux"
	polochon "github.com/odwrtw/polochon/lib"
	"gitlab.quimbo.fr/odwrtw/canape-sql/src/internal/web"
)

// GetDetailsHandler retrieves details for a movie
func GetDetailsHandler(env *web.Env, w http.ResponseWriter, r *http.Request) error {
	vars := mux.Vars(r)
	id := vars["id"]

	s := New(id)
	if err := s.GetDetails(env, false); err != nil {
		return err
	}
	if err := s.GetEpisodes(env); err != nil {
		return err
	}

	return env.RenderJSON(w, s)
}

// SearchShow will search a show
func SearchShow(env *web.Env, w http.ResponseWriter, r *http.Request) error {
	key := r.FormValue("key")
	if key == "" {
		return env.RenderError(w, errors.New("no given key"))
	}

	var shows []*polochon.Show
	searchers := env.Config.ShowSearchers
	for _, searcher := range searchers {
		result, err := searcher.SearchShow(key, env.Log)
		if err != nil {
			env.Log.Errorf("error while searching show : %s", err)
			continue
		}
		shows = append(shows, result...)
	}

	env.Log.Debugf("got %d shows doing search %q", len(shows), key)
	showList := []*Show{}
	for _, s := range shows {
		show := New(s.ImdbID)
		err := show.GetDetails(env, false)
		if err != nil {
			env.Log.Errorf("error while getting show details : %s", err)
			continue
		}
		showList = append(showList, show)
	}

	return env.RenderJSON(w, showList)
}
